﻿param([string]$OctopusKey="")

$ErrorActionPreference = 'Stop'

# All PowerShell scripts invoked by Calamari will be bootstrapped using this script. This script:
#  1. Declares/overrides various functions for scripts to use
#  2. Loads the $OctopusParameters variables
#  3. Sets a few defaults, like aborting scripts when an error is encountered
#  4. Invokes (using dot-sourcing) the target PowerShell script

# -----------------------------------------------------------------
# Functions
# -----------------------------------------------------------------

function Log-VersionTable
{
	Write-Verbose ($PSVersionTable | Out-String)
}

function Log-EnvironmentInformation
{
	if ($OctopusParameters.ContainsKey("Octopus.Action.Script.SuppressEnvironmentLogging")) {
		if ($OctopusParameters["Octopus.Action.Script.SuppressEnvironmentLogging"] -eq "True") {
			return;
		}
	}

	Write-Host "##octopus[stdout-verbose]"
	Write-Host "PowerShell Environment Information:"
	SafelyLog-EnvironmentVars
	SafelyLog-PathVars
	SafelyLog-ProcessVars
	SafelyLog-ComputerInfoVars
	Write-Host "##octopus[stdout-default]"
}

function SafelyLog-EnvironmentVars
{
	Try
	{
		$operatingSystem = [System.Environment]::OSVersion.ToString()
		Write-Host "  OperatingSystem: $($operatingSystem)"
		
		$osBitVersion = If ([System.Environment]::Is64BitOperatingSystem) {"x64"} Else {"x86"}
		Write-Host "  OsBitVersion: $($osBitVersion)"

		$is64BitProcess = [System.Environment]::Is64BitProcess.ToString()
		Write-Host "  Is64BitProcess: $($is64BitProcess)"

		$currentUser = [System.Security.Principal.WindowsIdentity]::GetCurrent().Name
		Write-Host "  CurrentUser: $($currentUser)"

		$machineName = [System.Environment]::MachineName
		Write-Host "  MachineName: $($machineName)"

		$processorCount = [System.Environment]::ProcessorCount.ToString()
		Write-Host "  ProcessorCount: $($processorCount)"
	}
	Catch
	{
		# silently fail.
	}
}

function SafelyLog-PathVars
{
	Try
	{
		$currentDirectory = [System.IO.Directory]::GetCurrentDirectory()
		Write-Host "  CurrentDirectory: $($currentDirectory)"

		$currentLocation = Get-Location
		Write-Host "  CurrentLocation: $($currentLocation)"
		
		$tempPath = [System.IO.Path]::GetTempPath()
		Write-Host "  TempDirectory: $($tempPath)"
	}
	Catch
	{
		# silently fail.
	}
}

function SafelyLog-ProcessVars
{
	Try
	{
		$hostProcess = [System.Diagnostics.Process]::GetCurrentProcess().ProcessName
		Write-Host "  HostProcessName: $($hostProcess)"
	}
	Catch
	{
		# silently fail.
	}
}

function SafelyLog-ComputerInfoVars
{
	Try
	{
		$OperatingSystem = (Get-WmiObject Win32_OperatingSystem)

		$totalVisibleMemorySize = $OperatingSystem.TotalVisibleMemorySize
		Write-Host "  TotalPhysicalMemory: $($totalVisibleMemorySize) KB"

		$freePhysicalMemory = $OperatingSystem.FreePhysicalMemory
		Write-Host "  AvailablePhysicalMemory: $($freePhysicalMemory) KB"
	}
	Catch
	{
		# silently fail.
	}
}

function Import-ScriptModule([string]$moduleName, [string]$moduleFilePath)
{
	Try 
	{
		Write-Verbose "Importing Script Module '$moduleName' from '$moduleFilePath'"
		Import-Module $moduleFilePath
	}
	Catch
	{
		Write-Warning "Failed to import Script Module '$moduleName'"
		Throw
	}
	Finally
	{
		# Once we've loaded (or failed to load) the script module, 
		# delete the script module file from the filesystem
		# https://github.com/OctopusDeploy/Issues/issues/3895
		Remove-Item $moduleFilePath -Force -ErrorAction SilentlyContinue
	}
}

function Convert-ServiceMessageValue([string]$value)
{
	$valueBytes = [System.Text.Encoding]::UTF8.GetBytes($value)
	return [Convert]::ToBase64String($valueBytes)
}

function Set-OctopusVariable([string]$name, [string]$value) 
{
	$name = Convert-ServiceMessageValue($name)
	$value = Convert-ServiceMessageValue($value)

	Write-Host "##octopus[setVariable name='$($name)' value='$($value)']"
}

function Fail-Step([string] $message)
{
	if($message)
	{
		$message = Convert-ServiceMessageValue($message)
		Write-Host "##octopus[resultMessage message='$($message)']"
	}
	exit -1
}

function New-OctopusArtifact([string]$path, [string]$name="""") 
{
	if ((Test-Path $path) -eq $false) {
		Write-Verbose "There is no file at '$path' right now. Writing the service message just in case the file is available when the artifacts are collected at a later point in time."
	}

	if ($name -eq """")	{
		$name = [System.IO.Path]::GetFileName($path)
	}
	$servicename = Convert-ServiceMessageValue($name)

	$length = ([System.IO.FileInfo]$path).Length;
	if (!$length) {
		$length = 0;
	}
	$length = Convert-ServiceMessageValue($length.ToString());

	$path = $ExecutionContext.SessionState.Path.GetUnresolvedProviderPathFromPSPath($path)
	$path = [System.IO.Path]::GetFullPath($path)
    $servicepath = Convert-ServiceMessageValue($path)

    Write-Verbose "Artifact $name will be collected from $path after this step completes"
	Write-Host "##octopus[createArtifact path='$($servicepath)' name='$($servicename)' length='$($length)']"
}

function Write-Debug([string]$message)
{
	Write-Verbose $message
}

function Write-Verbose([string]$message)
{
	Write-Host "##octopus[stdout-verbose]"
	Write-Host $message
	Write-Host "##octopus[stdout-default]"
}

function Write-Highlight([string]$message)
{
	Write-Host "##octopus[stdout-highlight]"
	Write-Host $message
	Write-Host "##octopus[stdout-default]"
}

function Write-Wait([string]$message)
{
	Write-Host "##octopus[stdout-wait]"
	Write-Host $message
	Write-Host "##octopus[stdout-default]"
}

function Write-Warning()
{
	[CmdletBinding()]
	param([string]$message)

	if ($WarningPreference -eq 'SilentlyContinue') {
		return
	}
	Write-Host "##octopus[stdout-warning]"
	Write-Host $message
	Write-Host "##octopus[stdout-default]"
}

function Decrypt-Variables($iv, $Encrypted) 
{
    function ConvertFromBase64String($str)
    {
        # "nul" is a special string used by Calamari to represent null. "null" is not used as it is a valid Base64 string. 
        if($str -eq "nul")
        {
            return $null;
        }
        else
        {
            [System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String($str))
        }
    }

    $parameters = New-Object 'System.Collections.Generic.Dictionary[String,String]' (,[System.StringComparer]::OrdinalIgnoreCase)

	# Try AesCryptoServiceProvider first (requires .NET 3.5+), otherwise fall back to RijndaelManaged (.NET 2.0)
	# Note using RijndaelManaged will fail in FIPS compliant environments: https://support.microsoft.com/en-us/kb/811833
	$algorithm = $null
	try {
		Add-Type -AssemblyName System.Core
		$algorithm = [System.Security.Cryptography.SymmetricAlgorithm] (New-Object System.Security.Cryptography.AesCryptoServiceProvider)
	} catch {
		Write-Verbose "Could not load AesCryptoServiceProvider, falling back to RijndaelManaged (.NET 2.0)."
		$algorithm = [System.Security.Cryptography.SymmetricAlgorithm] (New-Object System.Security.Cryptography.RijndaelManaged)
	}

	$algorithm.Mode = [System.Security.Cryptography.CipherMode]::CBC
	$algorithm.Padding = [System.Security.Cryptography.PaddingMode]::PKCS7
	$algorithm.KeySize = 128
	$algorithm.BlockSize = 128 # AES is just Rijndael with a fixed block size
	$algorithm.Key = [System.Convert]::FromBase64String($OctopusKey)
	$algorithm.IV =[System.Convert]::FromBase64String($iv)
	$decryptor = [System.Security.Cryptography.ICryptoTransform]$algorithm.CreateDecryptor()

	$memoryStream = new-Object IO.MemoryStream @(,[System.Convert]::FromBase64String($Encrypted)) 
	$cryptoStream = new-Object Security.Cryptography.CryptoStream $memoryStream,$decryptor,"Read" 
	$streamReader = new-Object IO.StreamReader $cryptoStream 
	while($streamReader.EndOfStream -eq $false)
    {
        $parts = $streamReader.ReadLine().Split("$")
        # The seemingly superfluous '-as' below was for PowerShell 2.0.  Without it, a cast exception was thrown when trying to add the object to a generic collection. 
        $parameters[(ConvertFromBase64String $parts[0])] = ConvertFromBase64String $parts[1] -as [string]
    }
	$streamReader.Dispose() | Out-Null
	$cryptoStream.Dispose() | Out-Null
	$memoryStream.Dispose() | Out-Null

	# RijndaelManaged/RijndaelManagedTransform implemented IDiposable explicitly
	[System.IDisposable].GetMethod("Dispose").Invoke($decryptor, @()) | Out-Null
	[System.IDisposable].GetMethod("Dispose").Invoke($algorithm, @()) | Out-Null
	
	return $parameters
}

function Initialize-ProxySettings() 
{
	$proxyUsername = $env:TentacleProxyUsername
	$proxyPassword = $env:TentacleProxyPassword
	$proxyHost = $env:TentacleProxyHost
	[int]$proxyPort = $env:TentacleProxyPort
	
	$useSystemProxy = [string]::IsNullOrEmpty($proxyHost) 
	
	if($useSystemProxy)
	{
		$proxy = [System.Net.WebRequest]::GetSystemWebProxy()
	}	
	else
	{
		$proxyUri = [System.Uri]"http://${proxyHost}:$proxyPort"
		$proxy = New-Object System.Net.WebProxy($proxyUri)
	}

	if ([string]::IsNullOrEmpty($proxyUsername)) 
	{
		if($useSystemProxy)
		{
			$proxy.Credentials = [System.Net.CredentialCache]::DefaultCredentials
		}
		else
		{
			$proxy.Credentials = New-Object System.Net.NetworkCredential("","")
		}
	}
	else 
	{
		$proxy.Credentials = New-Object System.Net.NetworkCredential($proxyUsername, $proxyPassword)
	}

	[System.Net.WebRequest]::DefaultWebProxy = $proxy
}

function Execute-WithRetry([ScriptBlock] $command, [int] $maxFailures = 3, [int] $sleepBetweenFailures = 1) {
	$attemptCount = 0
	$operationIncomplete = $true

	while ($operationIncomplete -and $attemptCount -lt $maxFailures) {
		$attemptCount = ($attemptCount + 1)

		if ($attemptCount -ge 2) {
			Write-Host "Waiting for $sleepBetweenFailures seconds before retrying..."
			Start-Sleep -s $sleepBetweenFailures
			Write-Host "Retrying..."
		}

		try {
			& $command

			$operationIncomplete = $false
		} catch [System.Exception] {
			if ($attemptCount -lt ($maxFailures)) {
				Write-Host ("Attempt $attemptCount of $maxFailures failed: " + $_.Exception.Message)
			} else {
				throw
			}
		}
	}
}

function Import-CalamariModules() {
	if ($OctopusParameters.ContainsKey("Octopus.Calamari.Bootstrapper.ModulePaths")) {
		$calamariModulePaths = $OctopusParameters["Octopus.Calamari.Bootstrapper.ModulePaths"].Split(";", [StringSplitOptions]'RemoveEmptyEntries')
		foreach ($calamariModulePath in $calamariModulePaths) {
		    if($calamariModulePath.EndsWith(".psd1")) {
		        Import-Module –Name $calamariModulePath.Replace("{{TentacleHome}}", $env:TentacleHome)
		    } else {
        		$env:PSModulePath = $calamariModulePath + ";" + $env:PSModulePath
		    }
		}
	}
}

Log-VersionTable

# -----------------------------------------------------------------
# Variables
# -----------------------------------------------------------------

$MaximumVariableCount=32768
$OctopusParameters = Decrypt-Variables 'F1blw9hOZBnH9+wMYzhr4A==' @'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'@

if (-Not (test-path variable:global:OctopusAgentProgramDirectoryPath)) {
  ${OctopusAgentProgramDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BZ2VudC5Qcm9ncmFtRGlyZWN0b3J5UGF0aA=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentId)) {
  ${OctopusDeploymentId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50Lklk"))]
}
if (-Not (test-path variable:global:OctopusDeploymentName)) {
  ${OctopusDeploymentName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50Lk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreated)) {
  ${OctopusDeploymentCreated} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWQ="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedUtc)) {
  ${OctopusDeploymentCreatedUtc} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRVdGM="))]
}
if (-Not (test-path variable:global:OctopusDeploymentComments)) {
  ${OctopusDeploymentComments} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNvbW1lbnRz"))]
}
if (-Not (test-path variable:global:OctopusDeploymentForcePackageDownload)) {
  ${OctopusDeploymentForcePackageDownload} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkZvcmNlUGFja2FnZURvd25sb2Fk"))]
}
if (-Not (test-path variable:global:OctopusDeploymentSpecificMachines)) {
  ${OctopusDeploymentSpecificMachines} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LlNwZWNpZmljTWFjaGluZXM="))]
}
if (-Not (test-path variable:global:OctopusDeploymentExcludedMachines)) {
  ${OctopusDeploymentExcludedMachines} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkV4Y2x1ZGVkTWFjaGluZXM="))]
}
if (-Not (test-path variable:global:OctopusProjectId)) {
  ${OctopusProjectId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5Qcm9qZWN0Lklk"))]
}
if (-Not (test-path variable:global:OctopusProjectName)) {
  ${OctopusProjectName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5Qcm9qZWN0Lk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusProjectGroupId)) {
  ${OctopusProjectGroupId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5Qcm9qZWN0R3JvdXAuSWQ="))]
}
if (-Not (test-path variable:global:OctopusProjectGroupName)) {
  ${OctopusProjectGroupName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5Qcm9qZWN0R3JvdXAuTmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusEnvironmentId)) {
  ${OctopusEnvironmentId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5FbnZpcm9ubWVudC5JZA=="))]
}
if (-Not (test-path variable:global:OctopusEnvironmentName)) {
  ${OctopusEnvironmentName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5FbnZpcm9ubWVudC5OYW1l"))]
}
if (-Not (test-path variable:global:OctopusEnvironmentSortOrder)) {
  ${OctopusEnvironmentSortOrder} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5FbnZpcm9ubWVudC5Tb3J0T3JkZXI="))]
}
if (-Not (test-path variable:global:OctopusReleaseId)) {
  ${OctopusReleaseId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLklk"))]
}
if (-Not (test-path variable:global:OctopusReleaseNumber)) {
  ${OctopusReleaseNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLk51bWJlcg=="))]
}
if (-Not (test-path variable:global:OctopusReleaseNotes)) {
  ${OctopusReleaseNotes} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLk5vdGVz"))]
}
if (-Not (test-path variable:global:OctopusTaskId)) {
  ${OctopusTaskId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UYXNrLklk"))]
}
if (-Not (test-path variable:global:OctopusTaskName)) {
  ${OctopusTaskName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UYXNrLk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusTaskQueueTime)) {
  ${OctopusTaskQueueTime} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UYXNrLlF1ZXVlVGltZQ=="))]
}
if (-Not (test-path variable:global:OctopusTaskQueueTimeExpiry)) {
  ${OctopusTaskQueueTimeExpiry} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UYXNrLlF1ZXVlVGltZUV4cGlyeQ=="))]
}
if (-Not (test-path variable:global:OctopusReleaseChannelId)) {
  ${OctopusReleaseChannelId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLkNoYW5uZWwuSWQ="))]
}
if (-Not (test-path variable:global:OctopusReleaseChannelName)) {
  ${OctopusReleaseChannelName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLkNoYW5uZWwuTmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusWebBaseUrl)) {
  ${OctopusWebBaseUrl} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5XZWIuQmFzZVVybA=="))]
}
if (-Not (test-path variable:global:OctopusWebDeploymentLink)) {
  ${OctopusWebDeploymentLink} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5XZWIuRGVwbG95bWVudExpbms="))]
}
if (-Not (test-path variable:global:OctopusWebReleaseLink)) {
  ${OctopusWebReleaseLink} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5XZWIuUmVsZWFzZUxpbms="))]
}
if (-Not (test-path variable:global:OctopusWebProjectLink)) {
  ${OctopusWebProjectLink} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5XZWIuUHJvamVjdExpbms="))]
}
if (-Not (test-path variable:global:OctopusActionNumber)) {
  ${OctopusActionNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uTnVtYmVy"))]
}
if (-Not (test-path variable:global:OctopusActionStepName)) {
  ${OctopusActionStepName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uU3RlcE5hbWU="))]
}
if (-Not (test-path variable:global:OctopusStepNumber)) {
  ${OctopusStepNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5TdGVwLk51bWJlcg=="))]
}
if (-Not (test-path variable:global:OctopusActionPackagePackageVersion)) {
  ${OctopusActionPackagePackageVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5QYWNrYWdlVmVyc2lvbg=="))]
}
if (-Not (test-path variable:global:OctopusStepId)) {
  ${OctopusStepId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5TdGVwLklk"))]
}
if (-Not (test-path variable:global:OctopusStepName)) {
  ${OctopusStepName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5TdGVwLk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusActionTargetRoles)) {
  ${OctopusActionTargetRoles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uVGFyZ2V0Um9sZXM="))]
}
if (-Not (test-path variable:global:OctopusActionId)) {
  ${OctopusActionId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uSWQ="))]
}
if (-Not (test-path variable:global:OctopusActionName)) {
  ${OctopusActionName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uTmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusActionPackageAutomaticallyRunConfigurationTransformationFiles)) {
  ${OctopusActionPackageAutomaticallyRunConfigurationTransformationFiles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5BdXRvbWF0aWNhbGx5UnVuQ29uZmlndXJhdGlvblRyYW5zZm9ybWF0aW9uRmlsZXM="))]
}
if (-Not (test-path variable:global:OctopusActionPackageAutomaticallyUpdateAppSettingsAndConnectionStrings)) {
  ${OctopusActionPackageAutomaticallyUpdateAppSettingsAndConnectionStrings} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5BdXRvbWF0aWNhbGx5VXBkYXRlQXBwU2V0dGluZ3NBbmRDb25uZWN0aW9uU3RyaW5ncw=="))]
}
if (-Not (test-path variable:global:OctopusActionEnabledFeatures)) {
  ${OctopusActionEnabledFeatures} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uRW5hYmxlZEZlYXR1cmVz"))]
}
if (-Not (test-path variable:global:OctopusActionPackageDownloadOnTentacle)) {
  ${OctopusActionPackageDownloadOnTentacle} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5Eb3dubG9hZE9uVGVudGFjbGU="))]
}
if (-Not (test-path variable:global:OctopusActionPackageFeedId)) {
  ${OctopusActionPackageFeedId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5GZWVkSWQ="))]
}
if (-Not (test-path variable:global:OctopusActionPackagePackageId)) {
  ${OctopusActionPackagePackageId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5QYWNrYWdlSWQ="))]
}
if (-Not (test-path variable:global:OctopusActionPackageCustomInstallationDirectory)) {
  ${OctopusActionPackageCustomInstallationDirectory} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5DdXN0b21JbnN0YWxsYXRpb25EaXJlY3Rvcnk="))]
}
if (-Not (test-path variable:global:OctopusActionPackageCustomInstallationDirectoryShouldBePurgedBeforeDeployment)) {
  ${OctopusActionPackageCustomInstallationDirectoryShouldBePurgedBeforeDeployment} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5DdXN0b21JbnN0YWxsYXRpb25EaXJlY3RvcnlTaG91bGRCZVB1cmdlZEJlZm9yZURlcGxveW1lbnQ="))]
}
if (-Not (test-path variable:global:OctopusActionCustomScriptsDeployps1)) {
  ${OctopusActionCustomScriptsDeployps1} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uQ3VzdG9tU2NyaXB0cy5EZXBsb3kucHMx"))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedById)) {
  ${OctopusDeploymentCreatedById} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRCeS5JZA=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedByUsername)) {
  ${OctopusDeploymentCreatedByUsername} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRCeS5Vc2VybmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedByDisplayName)) {
  ${OctopusDeploymentCreatedByDisplayName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRCeS5EaXNwbGF5TmFtZQ=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentCreatedByEmailAddress)) {
  ${OctopusDeploymentCreatedByEmailAddress} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LkNyZWF0ZWRCeS5FbWFpbEFkZHJlc3M="))]
}
if (-Not (test-path variable:global:OctopusTentacleCurrentDeploymentRetentionPolicySubset)) {
  ${OctopusTentacleCurrentDeploymentRetentionPolicySubset} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5DdXJyZW50RGVwbG95bWVudC5SZXRlbnRpb25Qb2xpY3lTdWJzZXQ="))]
}
if (-Not (test-path variable:global:OctopusRetentionPolicySet)) {
  ${OctopusRetentionPolicySet} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c1JldGVudGlvblBvbGljeVNldA=="))]
}
if (-Not (test-path variable:global:OctopusRetentionPolicyItemsToKeep)) {
  ${OctopusRetentionPolicyItemsToKeep} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c1JldGVudGlvblBvbGljeUl0ZW1zVG9LZWVw"))]
}
if (-Not (test-path variable:global:OctopusUseGuidedFailure)) {
  ${OctopusUseGuidedFailure} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c1VzZUd1aWRlZEZhaWx1cmU="))]
}
if (-Not (test-path variable:global:InstallDir)) {
  ${InstallDir} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("SW5zdGFsbERpcg=="))]
}
if (-Not (test-path variable:global:OctopusReleasePreviousId)) {
  ${OctopusReleasePreviousId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLlByZXZpb3VzLklk"))]
}
if (-Not (test-path variable:global:OctopusReleasePreviousNumber)) {
  ${OctopusReleasePreviousNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLlByZXZpb3VzLk51bWJlcg=="))]
}
if (-Not (test-path variable:global:OctopusReleasePreviousForEnvironmentId)) {
  ${OctopusReleasePreviousForEnvironmentId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLlByZXZpb3VzRm9yRW52aXJvbm1lbnQuSWQ="))]
}
if (-Not (test-path variable:global:OctopusReleasePreviousForEnvironmentNumber)) {
  ${OctopusReleasePreviousForEnvironmentNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLlByZXZpb3VzRm9yRW52aXJvbm1lbnQuTnVtYmVy"))]
}
if (-Not (test-path variable:global:OctopusReleaseCurrentForEnvironmentId)) {
  ${OctopusReleaseCurrentForEnvironmentId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLkN1cnJlbnRGb3JFbnZpcm9ubWVudC5JZA=="))]
}
if (-Not (test-path variable:global:OctopusReleaseCurrentForEnvironmentNumber)) {
  ${OctopusReleaseCurrentForEnvironmentNumber} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5SZWxlYXNlLkN1cnJlbnRGb3JFbnZpcm9ubWVudC5OdW1iZXI="))]
}
if (-Not (test-path variable:global:OctopusDeploymentPreviousSuccessfulId)) {
  ${OctopusDeploymentPreviousSuccessfulId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50LlByZXZpb3VzU3VjY2Vzc2Z1bC5JZA=="))]
}
if (-Not (test-path variable:global:OctopusActionPackageNuGetPackageId)) {
  ${OctopusActionPackageNuGetPackageId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5OdUdldFBhY2thZ2VJZA=="))]
}
if (-Not (test-path variable:global:OctopusActionPackageNuGetPackageVersion)) {
  ${OctopusActionPackageNuGetPackageVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5OdUdldFBhY2thZ2VWZXJzaW9u"))]
}
if (-Not (test-path variable:global:OctopusActionPackageNuGetFeedId)) {
  ${OctopusActionPackageNuGetFeedId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5OdUdldEZlZWRJZA=="))]
}
if (-Not (test-path variable:global:OctopusDeploymentMachines)) {
  ${OctopusDeploymentMachines} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5EZXBsb3ltZW50Lk1hY2hpbmVz"))]
}
if (-Not (test-path variable:global:OctopusMachineId)) {
  ${OctopusMachineId} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLklk"))]
}
if (-Not (test-path variable:global:OctopusMachineName)) {
  ${OctopusMachineName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLk5hbWU="))]
}
if (-Not (test-path variable:global:OctopusTentacleAgentApplicationDirectoryPath)) {
  ${OctopusTentacleAgentApplicationDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5BZ2VudC5BcHBsaWNhdGlvbkRpcmVjdG9yeVBhdGg="))]
}
if (-Not (test-path variable:global:OctopusTentacleAgentInstanceName)) {
  ${OctopusTentacleAgentInstanceName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5BZ2VudC5JbnN0YW5jZU5hbWU="))]
}
if (-Not (test-path variable:global:OctopusTentacleAgentProgramDirectoryPath)) {
  ${OctopusTentacleAgentProgramDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5BZ2VudC5Qcm9ncmFtRGlyZWN0b3J5UGF0aA=="))]
}
if (-Not (test-path variable:global:OctopusMachineCommunicationStyle)) {
  ${OctopusMachineCommunicationStyle} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLkNvbW11bmljYXRpb25TdHlsZQ=="))]
}
if (-Not (test-path variable:global:OctopusMachineHostname)) {
  ${OctopusMachineHostname} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLkhvc3RuYW1l"))]
}
if (-Not (test-path variable:global:OctopusMachineRoles)) {
  ${OctopusMachineRoles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLlJvbGVz"))]
}
if (-Not (test-path variable:global:OctopusMachineTags)) {
  ${OctopusMachineTags} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLlRhZ3M="))]
}
if (-Not (test-path variable:global:OctopusMachineTenantIds)) {
  ${OctopusMachineTenantIds} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5NYWNoaW5lLlRlbmFudElkcw=="))]
}
if (-Not (test-path variable:global:OctopusTentacleCurrentDeploymentPackageFilePath)) {
  ${OctopusTentacleCurrentDeploymentPackageFilePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5DdXJyZW50RGVwbG95bWVudC5QYWNrYWdlRmlsZVBhdGg="))]
}
if (-Not (test-path variable:global:OctopusTentacleCurrentDeploymentTargetedRoles)) {
  ${OctopusTentacleCurrentDeploymentTargetedRoles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5DdXJyZW50RGVwbG95bWVudC5UYXJnZXRlZFJvbGVz"))]
}
if (-Not (test-path variable:global:envSystemDrive)) {
  ${envSystemDrive} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlN5c3RlbURyaXZl"))]
}
if (-Not (test-path variable:global:envProgramFilesx86)) {
  ${envProgramFilesx86} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlByb2dyYW1GaWxlcyh4ODYp"))]
}
if (-Not (test-path variable:global:envPath)) {
  ${envPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBhdGg="))]
}
if (-Not (test-path variable:global:envProgramW6432)) {
  ${envProgramW6432} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlByb2dyYW1XNjQzMg=="))]
}
if (-Not (test-path variable:global:envwindir)) {
  ${envwindir} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OndpbmRpcg=="))]
}
if (-Not (test-path variable:global:envPROCESSORIDENTIFIER)) {
  ${envPROCESSORIDENTIFIER} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9JREVOVElGSUVS"))]
}
if (-Not (test-path variable:global:envPROCESSOR_IDENTIFIER)) {
  ${envPROCESSOR_IDENTIFIER} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9JREVOVElGSUVS"))]
}
if (-Not (test-path variable:global:envTMP)) {
  ${envTMP} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRNUA=="))]
}
if (-Not (test-path variable:global:envPROCESSORARCHITECTURE)) {
  ${envPROCESSORARCHITECTURE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9BUkNISVRFQ1RVUkU="))]
}
if (-Not (test-path variable:global:envPROCESSOR_ARCHITECTURE)) {
  ${envPROCESSOR_ARCHITECTURE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9BUkNISVRFQ1RVUkU="))]
}
if (-Not (test-path variable:global:envPATHEXT)) {
  ${envPATHEXT} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBBVEhFWFQ="))]
}
if (-Not (test-path variable:global:envAgentProgramDirectoryPath)) {
  ${envAgentProgramDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFnZW50UHJvZ3JhbURpcmVjdG9yeVBhdGg="))]
}
if (-Not (test-path variable:global:envPROCESSORREVISION)) {
  ${envPROCESSORREVISION} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9SRVZJU0lPTg=="))]
}
if (-Not (test-path variable:global:envPROCESSOR_REVISION)) {
  ${envPROCESSOR_REVISION} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9SRVZJU0lPTg=="))]
}
if (-Not (test-path variable:global:envTEMP)) {
  ${envTEMP} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRFTVA="))]
}
if (-Not (test-path variable:global:envUSERPROFILE)) {
  ${envUSERPROFILE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJQUk9GSUxF"))]
}
if (-Not (test-path variable:global:envTentacleVersion)) {
  ${envTentacleVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlVmVyc2lvbg=="))]
}
if (-Not (test-path variable:global:envTentacleJournal)) {
  ${envTentacleJournal} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlSm91cm5hbA=="))]
}
if (-Not (test-path variable:global:envTentacleApplications)) {
  ${envTentacleApplications} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlQXBwbGljYXRpb25z"))]
}
if (-Not (test-path variable:global:envTentacleProgramDirectoryPath)) {
  ${envTentacleProgramDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlUHJvZ3JhbURpcmVjdG9yeVBhdGg="))]
}
if (-Not (test-path variable:global:envTentacleInstanceName)) {
  ${envTentacleInstanceName} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlSW5zdGFuY2VOYW1l"))]
}
if (-Not (test-path variable:global:envUSERDNSDOMAIN)) {
  ${envUSERDNSDOMAIN} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJETlNET01BSU4="))]
}
if (-Not (test-path variable:global:envFPNOHOSTCHECK)) {
  ${envFPNOHOSTCHECK} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkZQX05PX0hPU1RfQ0hFQ0s="))]
}
if (-Not (test-path variable:global:envFP_NO_HOST_CHECK)) {
  ${envFP_NO_HOST_CHECK} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkZQX05PX0hPU1RfQ0hFQ0s="))]
}
if (-Not (test-path variable:global:envCommonProgramFiles)) {
  ${envCommonProgramFiles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNvbW1vblByb2dyYW1GaWxlcw=="))]
}
if (-Not (test-path variable:global:envTentacleCertificateSignatureAlgorithm)) {
  ${envTentacleCertificateSignatureAlgorithm} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlQ2VydGlmaWNhdGVTaWduYXR1cmVBbGdvcml0aG0="))]
}
if (-Not (test-path variable:global:envProgramData)) {
  ${envProgramData} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlByb2dyYW1EYXRh"))]
}
if (-Not (test-path variable:global:envHOMEPATH)) {
  ${envHOMEPATH} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkhPTUVQQVRI"))]
}
if (-Not (test-path variable:global:envCOMPUTERNAME)) {
  ${envCOMPUTERNAME} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNPTVBVVEVSTkFNRQ=="))]
}
if (-Not (test-path variable:global:envTentacleProxyPort)) {
  ${envTentacleProxyPort} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlUHJveHlQb3J0"))]
}
if (-Not (test-path variable:global:envALLUSERSPROFILE)) {
  ${envALLUSERSPROFILE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFMTFVTRVJTUFJPRklMRQ=="))]
}
if (-Not (test-path variable:global:envCommonProgramW6432)) {
  ${envCommonProgramW6432} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNvbW1vblByb2dyYW1XNjQzMg=="))]
}
if (-Not (test-path variable:global:envTentacleHome)) {
  ${envTentacleHome} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlSG9tZQ=="))]
}
if (-Not (test-path variable:global:envASPNETENV)) {
  ${envASPNETENV} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFTUE5FVF9FTlY="))]
}
if (-Not (test-path variable:global:envASPNET_ENV)) {
  ${envASPNET_ENV} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFTUE5FVF9FTlY="))]
}
if (-Not (test-path variable:global:envCommonProgramFilesx86)) {
  ${envCommonProgramFilesx86} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNvbW1vblByb2dyYW1GaWxlcyh4ODYp"))]
}
if (-Not (test-path variable:global:envHOMEDRIVE)) {
  ${envHOMEDRIVE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkhPTUVEUklWRQ=="))]
}
if (-Not (test-path variable:global:envSystemRoot)) {
  ${envSystemRoot} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlN5c3RlbVJvb3Q="))]
}
if (-Not (test-path variable:global:envNUMBEROFPROCESSORS)) {
  ${envNUMBEROFPROCESSORS} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52Ok5VTUJFUl9PRl9QUk9DRVNTT1JT"))]
}
if (-Not (test-path variable:global:envNUMBER_OF_PROCESSORS)) {
  ${envNUMBER_OF_PROCESSORS} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52Ok5VTUJFUl9PRl9QUk9DRVNTT1JT"))]
}
if (-Not (test-path variable:global:envOS)) {
  ${envOS} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52Ok9T"))]
}
if (-Not (test-path variable:global:envTentacleExecutablePath)) {
  ${envTentacleExecutablePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlRlbnRhY2xlRXhlY3V0YWJsZVBhdGg="))]
}
if (-Not (test-path variable:global:envProgramFiles)) {
  ${envProgramFiles} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlByb2dyYW1GaWxlcw=="))]
}
if (-Not (test-path variable:global:envComSpec)) {
  ${envComSpec} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkNvbVNwZWM="))]
}
if (-Not (test-path variable:global:envUSERNAME)) {
  ${envUSERNAME} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJOQU1F"))]
}
if (-Not (test-path variable:global:envLOGONSERVER)) {
  ${envLOGONSERVER} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkxPR09OU0VSVkVS"))]
}
if (-Not (test-path variable:global:envPSModulePath)) {
  ${envPSModulePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBTTW9kdWxlUGF0aA=="))]
}
if (-Not (test-path variable:global:envAPPDATA)) {
  ${envAPPDATA} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkFQUERBVEE="))]
}
if (-Not (test-path variable:global:envUSERDOMAIN)) {
  ${envUSERDOMAIN} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJET01BSU4="))]
}
if (-Not (test-path variable:global:envPROCESSORLEVEL)) {
  ${envPROCESSORLEVEL} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9MRVZFTA=="))]
}
if (-Not (test-path variable:global:envPROCESSOR_LEVEL)) {
  ${envPROCESSOR_LEVEL} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBST0NFU1NPUl9MRVZFTA=="))]
}
if (-Not (test-path variable:global:envLOCALAPPDATA)) {
  ${envLOCALAPPDATA} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OkxPQ0FMQVBQREFUQQ=="))]
}
if (-Not (test-path variable:global:envPSExecutionPolicyPreference)) {
  ${envPSExecutionPolicyPreference} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBTRXhlY3V0aW9uUG9saWN5UHJlZmVyZW5jZQ=="))]
}
if (-Not (test-path variable:global:envUSERDOMAINROAMINGPROFILE)) {
  ${envUSERDOMAINROAMINGPROFILE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJET01BSU5fUk9BTUlOR1BST0ZJTEU="))]
}
if (-Not (test-path variable:global:envUSERDOMAIN_ROAMINGPROFILE)) {
  ${envUSERDOMAIN_ROAMINGPROFILE} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlVTRVJET01BSU5fUk9BTUlOR1BST0ZJTEU="))]
}
if (-Not (test-path variable:global:envPUBLIC)) {
  ${envPUBLIC} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("ZW52OlBVQkxJQw=="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousInstallationOriginalInstalledPath)) {
  ${OctopusTentaclePreviousInstallationOriginalInstalledPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c0luc3RhbGxhdGlvbi5PcmlnaW5hbEluc3RhbGxlZFBhdGg="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousInstallationCustomInstallationDirectory)) {
  ${OctopusTentaclePreviousInstallationCustomInstallationDirectory} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c0luc3RhbGxhdGlvbi5DdXN0b21JbnN0YWxsYXRpb25EaXJlY3Rvcnk="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousInstallationPackageFilePath)) {
  ${OctopusTentaclePreviousInstallationPackageFilePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c0luc3RhbGxhdGlvbi5QYWNrYWdlRmlsZVBhdGg="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousInstallationPackageVersion)) {
  ${OctopusTentaclePreviousInstallationPackageVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c0luc3RhbGxhdGlvbi5QYWNrYWdlVmVyc2lvbg=="))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousSuccessfulInstallationOriginalInstalledPath)) {
  ${OctopusTentaclePreviousSuccessfulInstallationOriginalInstalledPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c1N1Y2Nlc3NmdWxJbnN0YWxsYXRpb24uT3JpZ2luYWxJbnN0YWxsZWRQYXRo"))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousSuccessfulInstallationCustomInstallationDirectory)) {
  ${OctopusTentaclePreviousSuccessfulInstallationCustomInstallationDirectory} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c1N1Y2Nlc3NmdWxJbnN0YWxsYXRpb24uQ3VzdG9tSW5zdGFsbGF0aW9uRGlyZWN0b3J5"))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousSuccessfulInstallationPackageFilePath)) {
  ${OctopusTentaclePreviousSuccessfulInstallationPackageFilePath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c1N1Y2Nlc3NmdWxJbnN0YWxsYXRpb24uUGFja2FnZUZpbGVQYXRo"))]
}
if (-Not (test-path variable:global:OctopusTentaclePreviousSuccessfulInstallationPackageVersion)) {
  ${OctopusTentaclePreviousSuccessfulInstallationPackageVersion} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5UZW50YWNsZS5QcmV2aW91c1N1Y2Nlc3NmdWxJbnN0YWxsYXRpb24uUGFja2FnZVZlcnNpb24="))]
}
if (-Not (test-path variable:global:OctopusOriginalPackageDirectoryPath)) {
  ${OctopusOriginalPackageDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c09yaWdpbmFsUGFja2FnZURpcmVjdG9yeVBhdGg="))]
}
if (-Not (test-path variable:global:OctopusActionPackageInstallationDirectoryPath)) {
  ${OctopusActionPackageInstallationDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1cy5BY3Rpb24uUGFja2FnZS5JbnN0YWxsYXRpb25EaXJlY3RvcnlQYXRo"))]
}
if (-Not (test-path variable:global:PackageInstallationDirectoryPath)) {
  ${PackageInstallationDirectoryPath} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("UGFja2FnZS5JbnN0YWxsYXRpb25EaXJlY3RvcnlQYXRo"))]
}
if (-Not (test-path variable:global:PackageExtractedFileCount)) {
  ${PackageExtractedFileCount} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("UGFja2FnZS5FeHRyYWN0ZWRGaWxlQ291bnQ="))]
}
if (-Not (test-path variable:global:OctopusAppliedXmlConfigTransforms)) {
  ${OctopusAppliedXmlConfigTransforms} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("T2N0b3B1c0FwcGxpZWRYbWxDb25maWdUcmFuc2Zvcm1z"))]
}
if (-Not (test-path variable:global:PackageCopiedFileCount)) {
  ${PackageCopiedFileCount} = $OctopusParameters[[System.Text.Encoding]::UTF8.GetString([Convert]::FromBase64String("UGFja2FnZS5Db3BpZWRGaWxlQ291bnQ="))]
}


# -----------------------------------------------------------------
# Script Modules - after variables
# -----------------------------------------------------------------



# -----------------------------------------------------------------
# Defaults
# -----------------------------------------------------------------

Initialize-ProxySettings

Log-EnvironmentInformation

# -----------------------------------------------------------------
# Invoke target script
# -----------------------------------------------------------------
Import-CalamariModules

# -----------------------------------------------------------------
# Invoke target script
# -----------------------------------------------------------------

. 'C:\inetpub\wwwroot\dev-assist.acr.org\simulator-npmdeploy\Octopus.Action.CustomScripts.Deploy.ps1' 

# -----------------------------------------------------------------
# Ensure we exit with whatever exit code the last exe used
# -----------------------------------------------------------------

if ((test-path variable:global:lastexitcode)) 
{
	exit $LastExitCode 
}
